ardt.datasets
=============

.. automodule:: ardt.datasets

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   AERDataset
   AERTrial
   AERTrialFilter
   MultiDataset
   ascertain
   cuads
   dreamer
   ml
